==> proshade-0.7.6.3.tar.gz: proshade-0.7.6.3/proshade/documentation/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "ProSHADE", "index.html", [
    [ "ProSHADE Documentation", "index.html", [
      [ "Introduction", "index.html#intro", null ],
      [ "Obtaining ProSHADE", "index.html#download", null ],
      [ "Index", "index.html#index", null ],
      [ "Installation", "index.html#install", [
        [ "Standard System Dependencies", "index.html#stdSys", null ],
        [ "Other dependencies", "index.html#otherDependencies", null ],
        [ "Installing on Windows", "index.html#winInstall", null ],
        [ "Installing using CMake on Unix", "index.html#installBehaviour", null ],
        [ "Installation using pip", "index.html#pipInstall", null ]
      ] ],
      [ "Input PDB files", "index.html#pdbInput", [
        [ "Spacegroups", "index.html#spaceGroups", null ],
        [ "Waters", "index.html#waterMols", null ],
        [ "Models", "index.html#firstModel", null ]
      ] ],
      [ "Using the ProSHADE binary", "index.html#proshadeBinary", [
        [ "Symmetry Detection", "index.html#symDetection", null ],
        [ "Shape similarity distances", "index.html#distDetection", null ],
        [ "Re-boxing structures", "index.html#reboxingUsage", null ],
        [ "Optimal rotation and translation", "index.html#overlayExample", null ]
      ] ],
      [ "Using the ProSHADE library", "index.html#libuse", [
        [ "Linking against the ProSHADE library", "index.html#liblink", null ],
        [ "Examples of ProSHADE library usage", "index.html#libexamples", null ]
      ] ],
      [ "Using the Python modules", "index.html#pyusage", [
        [ "Python module examples", "index.html#pyexamples", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Functions", "globals_func.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_pro_s_h_a_d_e_8cpp.html",
"_pro_s_h_a_d_e__settings_8hpp.html",
"class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9b08a8b6f9569c06cd183c924e6e80de",
"class_pro_s_h_a_d_e__settings.html#a754c633261eb363bfb496a234ace79e6"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> proshade-0.7.6.6.tar.gz: proshade-0.7.6.6/proshade/documentation/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "ProSHADE", "index.html", [
    [ "ProSHADE Documentation", "index.html", [
      [ "Introduction", "index.html#intro", null ],
      [ "Obtaining ProSHADE", "index.html#download", null ],
      [ "Index", "index.html#index", null ],
      [ "Installation", "index.html#install", [
        [ "Standard System Dependencies", "index.html#stdSys", null ],
        [ "Other dependencies", "index.html#otherDependencies", null ],
        [ "Installing on Windows", "index.html#winInstall", null ],
        [ "Installing using CMake on Unix", "index.html#installBehaviour", null ],
        [ "Installation using pip", "index.html#pipInstall", null ]
      ] ],
      [ "Input PDB files", "index.html#pdbInput", [
        [ "Spacegroups", "index.html#spaceGroups", null ],
        [ "Waters", "index.html#waterMols", null ],
        [ "Models", "index.html#firstModel", null ]
      ] ],
      [ "Using the ProSHADE binary", "index.html#proshadeBinary", [
        [ "Symmetry Detection", "index.html#symDetection", null ],
        [ "Shape similarity distances", "index.html#distDetection", null ],
        [ "Re-boxing structures", "index.html#reboxingUsage", null ],
        [ "Optimal rotation and translation", "index.html#overlayExample", null ]
      ] ],
      [ "Using the ProSHADE library", "index.html#libuse", [
        [ "Linking against the ProSHADE library", "index.html#liblink", null ],
        [ "Examples of ProSHADE library usage", "index.html#libexamples", null ]
      ] ],
      [ "Using the Python modules", "index.html#pyusage", [
        [ "Python module examples", "index.html#pyexamples", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Functions", "globals_func.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_pro_s_h_a_d_e_8cpp.html",
"_pro_s_h_a_d_e__peak_search_8hpp.html#a80392ad926f2c048de1cc20b47b4dff2",
"class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7e36b0876ff78682480a8ec22f3f5264",
"class_pro_s_h_a_d_e__settings.html#a4627b03c4064d3de15efb3ebbf57ed78",
"py_pro_s_h_a_d_e__distances_8cpp.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
